@@ -4,5 +4,7 @@ import re
 import base64
 import unicodedata
 import markdownify
+import copy
+import urllib.parse
 from bs4 import BeautifulSoup
 from datetime import datetime
\ No newline at end of file
